pub struct XORCryptor<T> { /* private fields */ }Implementations
Sourceimpl XORCryptor<V2>
impl XORCryptor<V2>
pub fn new_v2(seed: Option<usize>) -> Self
Sourcepub fn update_cipher(&mut self, key: &[u8], spice_seed: usize) -> XRCResult<()>
pub fn update_cipher(&mut self, key: &[u8], spice_seed: usize) -> XRCResult<()>
Used to for updating [cipher::Cipher] with
key and spice_seed.
spice_seed is multiplied by seed used
with XORCryptor::new_v2.
DO NOT call this if you don’t know what you are doing.
Sourcepub fn encrypt_vec(&mut self, key: &[u8], buffer: Vec<u8>) -> XRCResult<Vec<u8>>
pub fn encrypt_vec(&mut self, key: &[u8], buffer: Vec<u8>) -> XRCResult<Vec<u8>>
Encrypts the vector by randomizing cipher generation from keys.
Slower throughput due to chaining randomized cipher.
Sourcepub fn encrypt_v2(key: &[u8], buffer: Vec<u8>) -> XRCResult<Vec<u8>>
pub fn encrypt_v2(key: &[u8], buffer: Vec<u8>) -> XRCResult<Vec<u8>>
Encrypts the vector by randomizing cipher generation from keys.
Slower throughput due to chaining randomized cipher.
pub fn decrypt_vec(&mut self, key: &[u8], buffer: Vec<u8>) -> XRCResult<Vec<u8>>
Sourceimpl<T: XrcVersion> XORCryptor<T>
impl<T: XrcVersion> XORCryptor<T>
pub fn get_cipher(&self) -> &[usize]
Sourceimpl XORCryptor<V1>
impl XORCryptor<V1>
pub fn new_bytes(key: &[u8]) -> XRCResult<Self>
Sourcepub fn encrypt_vec(&self, buffer: Vec<u8>) -> Vec<u8> ⓘ
👎Deprecated
pub fn encrypt_vec(&self, buffer: Vec<u8>) -> Vec<u8> ⓘ
Encrypts the vector
IMPORTANT!
This method is NOT suitable for production use as it uses ECB. Hence, takes advantage of parallelism for higher through put
[Breaking Change]: Use Self::encrypt_v2 for more secure and suitable for production use
Sourcepub fn decrypt_vec(&self, buffer: Vec<u8>) -> Vec<u8> ⓘ
👎Deprecated
pub fn decrypt_vec(&self, buffer: Vec<u8>) -> Vec<u8> ⓘ
Decrypts the vector
IMPORTANT!
This method is NOT suitable for production use.
[Breaking Change]: Use Self::decrypt_v2.